Index: trunk/psModules/src/camera/pmFPAfile.h
===================================================================
--- trunk/psModules/src/camera/pmFPAfile.h	(revision 7480)
+++ trunk/psModules/src/camera/pmFPAfile.h	(revision 7589)
@@ -7,6 +7,6 @@
 *  @author EAM, IfA
 *
-*  @version $Revision: 1.2 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2006-06-10 03:01:29 $
+*  @version $Revision: 1.3 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2006-06-17 01:50:43 $
 *
 *  Copyright 2004-2005 Institute for Astronomy, University of Hawaii
@@ -58,6 +58,6 @@
     pmFPAfileState state;  // have we opened the file, etc?
 
-    pmFPAdepth fileDepth;  // what depth in the FPA hierarchy represents a unique file?
-    pmFPAdepth dataDepth;  // at what depth do we read/write the data segment?
+    pmFPALevel fileLevel;  // what level in the FPA hierarchy represents a unique file?
+    pmFPALevel dataLevel;  // at what level do we read/write the data segment?
 
     pmFPA *fpa;    // for I/O files, we carry a pointer to the complete fpa
@@ -80,4 +80,6 @@
     char *extname;   // the current name of an active file extension
 
+    bool save;
+
     // the following elements are used for WRITE-mode IMAGE-type pmFPAfiles to inform
     // the creation of a new image based on an existing image
@@ -85,4 +87,6 @@
     int xBin;    // desired binning in x direction
     int yBin;    // desired binning in y direction
+
+    psMetadata *camera;
     psMetadata *format;
 }
@@ -92,66 +96,6 @@
 pmFPAfile *pmFPAfileAlloc ();
 
-// load the pmFPAfile information from the camera configuration data
-pmFPAfile *pmFPAfileDefine (psMetadata *files, psMetadata *camera, pmFPA *fpa, char *name);
-
-// load the pmFPAfile information from the camera configuration data, constructing the needed fpa structure
-// XXX deprecate this function?
-// pmFPAfile *pmFPAfileConstruct (psMetadata *files, psMetadata *format, psMetadata *camera, char *name);
-
-// open the real file corresponding to the given pmFPAfile appropriate to the current view
-bool pmFPAfileOpen (pmFPAfile *file, const pmFPAview *view);
-
-// read from the real file corresponding to the given pmFPAfile for the current view
-bool pmFPAfileRead (pmFPAfile *file, const pmFPAview *view);
-
-bool pmFPAfileCreate (pmFPAfile *file, const pmFPAview *view);
-
-// write to the real file corresponding to the given pmFPAfile for the current view
-bool pmFPAfileWrite (pmFPAfile *file, const pmFPAview *view);
-
-// close the real file corresponding to the given pmFPAfile appropriate to the current view
-bool pmFPAfileClose (pmFPAfile *file, const pmFPAview *view);
-
-// free the data at this level
-bool pmFPAfileFreeData(pmFPAfile *file, const pmFPAview *view);
-
-// set the state of the specified pmFPAfile to active (state == true) or inactive
-// if name is NULL, set the state for all pmFPAfiles
-bool pmFPAfileActivate (psMetadata *files, bool state, char *name);
-
-// examine all pmFPAfiles listed in the files and perform the needed I/O operations (open,read,write,close)
-bool pmFPAfileIOChecks (psMetadata *files, const pmFPAview *view, pmFPAfilePlace place);
-
-// return an image corresponding to the current readout, from the specified file.  if the pmFPAfile does not
-// exist, construct the image using the given size and type (save it in a pmFPAfile??)
-// psImage *pmFPAfileReadoutImage (psMetadata *files, const pmFPAview *view, char *name, int Nx, int Ny, int type);
-
 // select the readout from the named pmFPAfile; if the named file does not exist,
 pmReadout *pmFPAfileThisReadout (psMetadata *files, const pmFPAview *view, const char *name);
-
-// create a file with the given name, assign it type "INTERNAL", and supply it with an image
-// of the requested dimensions. (image only, mask and weight are ignored)
-pmReadout *pmFPAfileCreateInternal (psMetadata *files, char *name, int Nx, int Ny, int type);
-
-// delete the INTERNAL file of the given name (if it exists)
-bool pmFPAfileDropInternal (psMetadata *files, char *name);
-
-// read an image into the current view
-bool pmFPAviewReadFitsImage (const pmFPAview *view, pmFPAfile *file);
-
-// write the components for the specified view
-bool pmFPAviewWriteFitsImage (const pmFPAview *view, pmFPAfile *file);
-
-// free the appropriate image containers
-bool pmFPAviewFreeFitsImage (const pmFPAview *view, pmFPAfile *file);
-
-// look for the given argname on the argument list.  find the give filename from the file rules
-pmFPAfile *pmFPAfileFromArgs (bool *found, pmConfig *config, char *filename, char *argname);
-
-// look for the given argname on the argument list.  find the give filename from the file rules
-pmFPAfile *pmFPAfileFromConf (bool *found, pmConfig *config, char *filename, pmFPA *input);
-
-// create a new output pmFPAfile based on an existing FPA
-pmFPAfile *pmFPAfileFromFPA (pmConfig *config, pmFPA *src, int xBin, int yBin, char *filename);
 
 // add the specified filename info (value) to the files of the given mode using the given reference name
